# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:
{
  imports = [
      ./hardware-configuration.nix
      ../common.nix
  ];

  jade = {
    desktop.enable = true;
  };

  # monitor control
  services.ddccontrol.enable = true;

  # Use the systemd-boot EFI boot loader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;
  # latest linux kernel
  boot.kernelPackages = pkgs.linuxPackages_latest;

  networking.hostName = "monosodium-glutamate-g";

  services.xserver.layout = "us";
  services.xserver.xkbVariant = "altgr-intl";

  hardware.bluetooth.enable = true;
  hardware.keyboard.uhk.enable = true;

  # missing: menu-qalc picom-jonaburg
  environment.systemPackages = with pkgs; [
    # TODO: clean up.
  ];

  environment.pathsToLink = [
    "/share/nix-direnv"
  ];

  services.blueman.enable = true;

  services.gnome.gnome-keyring.enable = true;
  programs.seahorse.enable = true;
  security.pam.services.jade.enableGnomeKeyring = true;

  # Copy the NixOS configuration file and link it from the resulting system
  # (/run/current-system/configuration.nix). This is useful in case you
  # accidentally delete configuration.nix.
  # system.copySystemConfiguration = true;

  # networking.firewall.allowedTCPPorts = [ 4713 ];
  systemd.services."NetworkManager-wait-online".enable = false;

  # release channel
  system.stateVersion = "22.05"; # Did you read the comment?
}

